pub struct CameraCapFlags(/* private fields */);Expand description
MAVLink bitmask enum CAMERA_CAP_FLAGS for common dialect.
Camera capability flags (Bitmap)
Implementations
Sourceimpl CameraCapFlags
impl CameraCapFlags
Sourcepub const CAPTURE_VIDEO: CameraCapFlags
pub const CAPTURE_VIDEO: CameraCapFlags
CAMERA_CAP_FLAGS_CAPTURE_VIDEO flag.
Camera is able to record video
Sourcepub const CAPTURE_IMAGE: CameraCapFlags
pub const CAPTURE_IMAGE: CameraCapFlags
CAMERA_CAP_FLAGS_CAPTURE_IMAGE flag.
Camera is able to capture images
Sourcepub const HAS_MODES: CameraCapFlags
pub const HAS_MODES: CameraCapFlags
CAMERA_CAP_FLAGS_HAS_MODES flag.
Camera has separate Video and Image/Photo modes (MAV_CMD_SET_CAMERA_MODE)
Sourcepub const CAN_CAPTURE_IMAGE_IN_VIDEO_MODE: CameraCapFlags
pub const CAN_CAPTURE_IMAGE_IN_VIDEO_MODE: CameraCapFlags
CAMERA_CAP_FLAGS_CAN_CAPTURE_IMAGE_IN_VIDEO_MODE flag.
Camera can capture images while in video mode
Sourcepub const CAN_CAPTURE_VIDEO_IN_IMAGE_MODE: CameraCapFlags
pub const CAN_CAPTURE_VIDEO_IN_IMAGE_MODE: CameraCapFlags
CAMERA_CAP_FLAGS_CAN_CAPTURE_VIDEO_IN_IMAGE_MODE flag.
Camera can capture videos while in Photo/Image mode
Sourcepub const HAS_IMAGE_SURVEY_MODE: CameraCapFlags
pub const HAS_IMAGE_SURVEY_MODE: CameraCapFlags
CAMERA_CAP_FLAGS_HAS_IMAGE_SURVEY_MODE flag.
Camera has image survey mode (MAV_CMD_SET_CAMERA_MODE)
Sourcepub const HAS_BASIC_ZOOM: CameraCapFlags
pub const HAS_BASIC_ZOOM: CameraCapFlags
CAMERA_CAP_FLAGS_HAS_BASIC_ZOOM flag.
Camera has basic zoom control (MAV_CMD_SET_CAMERA_ZOOM)
Sourcepub const HAS_BASIC_FOCUS: CameraCapFlags
pub const HAS_BASIC_FOCUS: CameraCapFlags
CAMERA_CAP_FLAGS_HAS_BASIC_FOCUS flag.
Camera has basic focus control (MAV_CMD_SET_CAMERA_FOCUS)
Sourcepub const HAS_VIDEO_STREAM: CameraCapFlags
pub const HAS_VIDEO_STREAM: CameraCapFlags
CAMERA_CAP_FLAGS_HAS_VIDEO_STREAM flag.
Camera has video streaming capabilities (request VIDEO_STREAM_INFORMATION with MAV_CMD_REQUEST_MESSAGE for video streaming info)
Sourcepub const HAS_TRACKING_POINT: CameraCapFlags
pub const HAS_TRACKING_POINT: CameraCapFlags
CAMERA_CAP_FLAGS_HAS_TRACKING_POINT flag.
Camera supports tracking of a point on the camera view.
Sourcepub const HAS_TRACKING_RECTANGLE: CameraCapFlags
pub const HAS_TRACKING_RECTANGLE: CameraCapFlags
CAMERA_CAP_FLAGS_HAS_TRACKING_RECTANGLE flag.
Camera supports tracking of a selection rectangle on the camera view.
Sourcepub const HAS_TRACKING_GEO_STATUS: CameraCapFlags
pub const HAS_TRACKING_GEO_STATUS: CameraCapFlags
CAMERA_CAP_FLAGS_HAS_TRACKING_GEO_STATUS flag.
Camera supports tracking geo status (CAMERA_TRACKING_GEO_STATUS).
Sourcepub const HAS_THERMAL_RANGE: CameraCapFlags
pub const HAS_THERMAL_RANGE: CameraCapFlags
CAMERA_CAP_FLAGS_HAS_THERMAL_RANGE flag.
Camera supports absolute thermal range (request CAMERA_THERMAL_RANGE with MAV_CMD_REQUEST_MESSAGE).
Sourceimpl CameraCapFlags
impl CameraCapFlags
Sourcepub const fn empty() -> CameraCapFlags
pub const fn empty() -> CameraCapFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> CameraCapFlags
pub const fn all() -> CameraCapFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<CameraCapFlags>
pub const fn from_bits(bits: u16) -> Option<CameraCapFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> CameraCapFlags
pub const fn from_bits_truncate(bits: u16) -> CameraCapFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> CameraCapFlags
pub const fn from_bits_retain(bits: u16) -> CameraCapFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<CameraCapFlags>
pub fn from_name(name: &str) -> Option<CameraCapFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: CameraCapFlags) -> bool
pub const fn intersects(&self, other: CameraCapFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: CameraCapFlags) -> bool
pub const fn contains(&self, other: CameraCapFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: CameraCapFlags)
pub fn insert(&mut self, other: CameraCapFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: CameraCapFlags)
pub fn remove(&mut self, other: CameraCapFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: CameraCapFlags)
pub fn toggle(&mut self, other: CameraCapFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: CameraCapFlags, value: bool)
pub fn set(&mut self, other: CameraCapFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: CameraCapFlags) -> CameraCapFlags
pub const fn intersection(self, other: CameraCapFlags) -> CameraCapFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: CameraCapFlags) -> CameraCapFlags
pub const fn union(self, other: CameraCapFlags) -> CameraCapFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: CameraCapFlags) -> CameraCapFlags
pub const fn difference(self, other: CameraCapFlags) -> CameraCapFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: CameraCapFlags) -> CameraCapFlags
pub const fn symmetric_difference(self, other: CameraCapFlags) -> CameraCapFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> CameraCapFlags
pub const fn complement(self) -> CameraCapFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl CameraCapFlags
impl CameraCapFlags
Sourcepub const fn iter(&self) -> Iter<CameraCapFlags> ⓘ
pub const fn iter(&self) -> Iter<CameraCapFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CameraCapFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<CameraCapFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.