pub struct SerialControlFlag(/* private fields */);Expand description
MAVLink bitmask enum SERIAL_CONTROL_FLAG for common dialect.
SERIAL_CONTROL flags (bitmask)
Implementations
Sourceimpl SerialControlFlag
impl SerialControlFlag
Sourcepub const REPLY: SerialControlFlag
pub const REPLY: SerialControlFlag
SERIAL_CONTROL_FLAG_REPLY flag.
Set if this is a reply
Sourcepub const RESPOND: SerialControlFlag
pub const RESPOND: SerialControlFlag
SERIAL_CONTROL_FLAG_RESPOND flag.
Set if the sender wants the receiver to send a response as another SERIAL_CONTROL message
Sourcepub const EXCLUSIVE: SerialControlFlag
pub const EXCLUSIVE: SerialControlFlag
SERIAL_CONTROL_FLAG_EXCLUSIVE flag.
Set if access to the serial port should be removed from whatever driver is currently using it, giving exclusive access to the SERIAL_CONTROL protocol. The port can be handed back by sending a request without this flag set
Sourcepub const BLOCKING: SerialControlFlag
pub const BLOCKING: SerialControlFlag
SERIAL_CONTROL_FLAG_BLOCKING flag.
Block on writes to the serial port
Sourcepub const MULTI: SerialControlFlag
pub const MULTI: SerialControlFlag
SERIAL_CONTROL_FLAG_MULTI flag.
Send multiple replies until port is drained
Sourceimpl SerialControlFlag
impl SerialControlFlag
Sourcepub const fn empty() -> SerialControlFlag
pub const fn empty() -> SerialControlFlag
Get a flags value with all bits unset.
Sourcepub const fn all() -> SerialControlFlag
pub const fn all() -> SerialControlFlag
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<SerialControlFlag>
pub const fn from_bits(bits: u8) -> Option<SerialControlFlag>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> SerialControlFlag
pub const fn from_bits_truncate(bits: u8) -> SerialControlFlag
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> SerialControlFlag
pub const fn from_bits_retain(bits: u8) -> SerialControlFlag
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SerialControlFlag>
pub fn from_name(name: &str) -> Option<SerialControlFlag>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SerialControlFlag) -> bool
pub const fn intersects(&self, other: SerialControlFlag) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: SerialControlFlag) -> bool
pub const fn contains(&self, other: SerialControlFlag) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: SerialControlFlag)
pub fn insert(&mut self, other: SerialControlFlag)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: SerialControlFlag)
pub fn remove(&mut self, other: SerialControlFlag)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SerialControlFlag)
pub fn toggle(&mut self, other: SerialControlFlag)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: SerialControlFlag, value: bool)
pub fn set(&mut self, other: SerialControlFlag, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SerialControlFlag) -> SerialControlFlag
pub const fn intersection(self, other: SerialControlFlag) -> SerialControlFlag
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: SerialControlFlag) -> SerialControlFlag
pub const fn union(self, other: SerialControlFlag) -> SerialControlFlag
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: SerialControlFlag) -> SerialControlFlag
pub const fn difference(self, other: SerialControlFlag) -> SerialControlFlag
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: SerialControlFlag,
) -> SerialControlFlag
pub const fn symmetric_difference( self, other: SerialControlFlag, ) -> SerialControlFlag
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> SerialControlFlag
pub const fn complement(self) -> SerialControlFlag
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl SerialControlFlag
impl SerialControlFlag
Sourcepub const fn iter(&self) -> Iter<SerialControlFlag> ⓘ
pub const fn iter(&self) -> Iter<SerialControlFlag> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SerialControlFlag> ⓘ
pub const fn iter_names(&self) -> IterNames<SerialControlFlag> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.